#ifndef _HAD_SIGNALS_H
#define _HAD_SIGNALS_H

/*
  signals.h -- signal handling functions
  Copyright (C) 1996, 1997, 1998, 1999, 2000 Dieter Baron

  This file is part of cftp, a fullscreen ftp client
  The author can be contacted at <dillo@giga.or.at>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/



extern volatile int sig_intr, sig_pipe, sig_alarm;

int signals_init(void);
void sig_end(int sno);
void sig_escape(int sno);
void sig_reenter(int sno);
void sig_remember(int sno);

#endif /* signals.h */
